#pragma once
#include <map>
static const std::map<std::string, std::string> SHADERS = {
{"CM.frag",
#include "./CM.frag.inc"
},
{"CM.glsl",
#include "./CM.glsl.inc"
},
{"border.frag",
#include "./border.frag.inc"
},
{"passthru.frag",
#include "./passthru.frag.inc"
},
{"quad.frag",
#include "./quad.frag.inc"
},
{"rgba.frag",
#include "./rgba.frag.inc"
},
{"rounding.glsl",
#include "./rounding.glsl.inc"
},
{"tex300.vert",
#include "./tex300.vert.inc"
},
};
